@@ -1,4 +1,4 @@
-      subroutine initdata(si,n1,n2,n3,nb,maxvalue)
+      subroutine initdata(si,n1,n2,n3,nb,maxvalue)      
 C
 C   project all values to (1,maxvalue) to avoid infinite estimates
 C
@@ -22,7 +22,7 @@ C
 C
 C   replace physically meaningless Si values by mean S0
 C
-      implicit logical(a-z)
+      implicit none
       integer n,nb,ls0,s0ind(ls0),siind(*)
       double precision si(nb,n),sinew(nb,n)
       logical ind(n)
@@ -64,7 +64,7 @@ C$OMP END PARALLEL
 C
 C   replace physically meaningless Si values by mean S0
 C
-      implicit logical(a-z)
+      implicit none
       integer n,nb,nb1,ls0,lsi,s0ind(ls0),siind(lsi)
       double precision si(nb,n),sinew(nb1,n)
       integer i,j1,j,ls0m1,changed
@@ -97,16 +97,16 @@ C$OMP DO SCHEDULE(STATIC)
          sinn(nb1)=changed
          DO j=1,nb1
             sinew(j,i)=sinn(j)
-         END DO         
+         END DO
       END DO
 C$OMP END DO NOWAIT
 C$OMP END PARALLEL
       RETURN
       END
-     
+
       subroutine mcorrlag(res,mask,n1,n2,n3,nv,sigma,mean,scorr,lag)
 
-      implicit logical(a-z)
+      implicit none
       integer n1,n2,n3,nv,lag(3)
       double precision scorr,res(nv,n1,n2,n3),sigma(n1,n2,n3),
      1       mean(n1,n2,n3)
@@ -149,7 +149,7 @@ C  correlation in x
       end
 
       subroutine msd(res,mask,n,nv,sigma,mean)
-      implicit logical(a-z)
+      implicit none
       integer n,nv
       double precision sigma(n),res(nv,n),mean(n)
       logical mask(n)
@@ -181,10 +181,10 @@ C$OMP END PARALLEL
 C$OMP FLUSH(mean,sigma)
       RETURN
       END
-      
+
       subroutine mcorr(res,mask,n1,n2,n3,nv,sigma,mean,scorr,l1,l2,l3)
 
-      implicit logical(a-z)
+      implicit none
       integer n1,n2,n3,nv,l1,l2,l3,lag(3),n
       double precision scorr(l1,l2,l3),res(nv,n1,n2,n3),
      1       sigma(n1,n2,n3),mean(n1,n2,n3)
@@ -215,7 +215,7 @@ C$OMP FLUSH(scorr)
       end
       subroutine thcorr(w,n1,n2,n3,scorr,l1,l2,l3)
 
-      implicit logical(a-z)
+      implicit none
       integer n1,n2,n3,l1,l2,l3,lag(3)
       double precision scorr(l1,l2,l3),w(n1,n2,n3)
       integer i1,i2,i3
@@ -245,7 +245,7 @@ C$OMP FLUSH(scorr)
 
       subroutine thcorlag(w,n1,n2,n3,scorr,lag)
 
-      implicit logical(a-z)
+      implicit none
       integer n1,n2,n3,lag(3)
       double precision scorr,w(n1,n2,n3)
       integer i1,i2,i3,c1,c2,c3,j1,j2,j3,l1,l2,l3
@@ -279,7 +279,7 @@ C
 C   assumes that we search for a connected region in segm==.TRUE.
 C   that contains seed voxel (i1,i2,i3)
 C   result: mask == .TRUE. if voxel is connected to seed
-      implicit logical (a-z)
+      implicit none
       integer n1,n2,n3,i1,i2,i3,ind1(*),ind2(*),ind3(*)
       logical final,mask(n1,n2,n3),segm(n1,n2,n3)
       integer j1,j2,j3,k,l1,l2,l3,lind,lind0,ichecked
@@ -348,7 +348,7 @@ C     first find pixel close to (i1,i2) with segm(j1,j2)=0
                      END IF
                   END DO
                END DO
-            END DO 
+            END DO
          END DO
          if(lind.eq.lind0) THEN
             final=.TRUE.
@@ -360,7 +360,7 @@ C     first find pixel close to (i1,i2) with segm(j1,j2)=0
       RETURN
       END
       subroutine getmask(s0,n1,n2,n3,ns,level,msize,prop,s0m,mask)
-      implicit logical (a-z) 
+      implicit none
       integer n1,n2,n3,ns,msize
       double precision  s0(n1,n2,n3,ns)
       double precision s0m(n1,n2,n3),prop,level
@@ -395,7 +395,7 @@ C
                   END DO
                END DO
                mask(i1,i2,i3)=.FALSE.
-               if(anz1/anz.gt.prop) mask(i1,i2,i3)=.TRUE.            
+               if(anz1/anz.gt.prop) mask(i1,i2,i3)=.TRUE.
             END DO
          END DO
       END DO
@@ -403,82 +403,11 @@ C
       END
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
 C
-C   Calculate exceedence probabilities in awstestprop
-C
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-      subroutine exceed(x,n,z,nz,exprob)
-      implicit logical (a-z)
-      integer n,nz
-      double precision x(n),z(nz),exprob(nz)
-      integer i,j
-      double precision sk,zj
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n,nz,x,z,exprob)
-C$OMP& PRIVATE(i,j,sk,zj)
-C$OMP DO SCHEDULE(GUIDED)
-      DO j=1,nz
-         sk=0.d0
-         zj=z(j)
-         DO i=1,n
-            if(x(i).gt.zj) sk=sk+1
-         END DO
-         exprob(j)=sk/n
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(exprob)
-      Return
-      End
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-C
-C  remove interior points from a cube, and return matrix of coords
-C
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-      subroutine rminteri(x,lx,n1,n2,n3,xcoord,nc,value)
-      implicit logical (a-z)
-      integer n1,n2,n3,xcoord(3,*),nc,x(n1,n2,n3),value(*)
-      logical lx(n1,n2,n3),sel
-      integer i1,i2,i3,k,a1,a2,a3,e1,e2,e3
-      k=1
-      DO i1=1,n1
-         a1=max(1,i1-1)
-         e1=min(n1,i1+1)
-         DO i2=1,n2
-            a2=max(1,i2-1)
-            e2=min(n2,i2+1)
-            DO i3=1,n3
-               a3=max(1,i3-1)
-               e3=min(n3,i3+1)
-               if(.not.lx(i1,i2,i3)) CYCLE
-               sel=.FALSE.
-               if(.not.lx(a1,i2,i3)) sel=.TRUE.
-               if(.not.lx(e1,i2,i3)) sel=.TRUE.
-               if(.not.lx(i1,a2,i3)) sel=.TRUE.
-               if(.not.lx(i1,e2,i3)) sel=.TRUE.
-               if(.not.lx(i1,i2,a3)) sel=.TRUE.
-               if(.not.lx(i1,i2,e3)) sel=.TRUE.
-C               if(a1.eq.1.or.a2.eq.1.or.a3.eq.1) sel=.TRUE.
-C               if(e1.eq.n1.or.e2.eq.n2.or.e3.eq.n3) sel=.TRUE.
-               if(sel) THEN
-                  xcoord(1,k)=i1
-                  xcoord(2,k)=i2
-                  xcoord(3,k)=i3
-                  value(k)=x(i1,i2,i3)
-                  k=k+1
-               END IF
-            END DO
-         END DO
-      END DO
-      nc=k-1
-      RETURN
-      END
-CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
-C
 C   Hypergeometric 1F1 NIST HB 13.2.2, 13.2.39, 13.2(iv)
 C
 CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
       subroutine hg1f1(a,b,z,n,fz)
-      implicit logical (a-z)
+      implicit none
       integer n
       double precision a,b,z(n),fz(n)
       integer i
@@ -495,7 +424,7 @@ CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
             ai=b-a
             if(zi.lt.-1400) THEN
                fz(i) = exp((-a)*log(-zi))*gofbai+5.6e-3+1.9e-3*b
-C   add +5.6e-3+1.9e-3*b to keep the function monotone 
+C   add +5.6e-3+1.9e-3*b to keep the function monotone
                CYCLE
             END IF
          ELSE
@@ -513,4 +442,173 @@ C   add +5.6e-3+1.9e-3*b to keep the function monotone
       END DO
       RETURN
       END
-      
+
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C     get rho from D (uses c(1,0,0,1,0,1) in case of inplausible D
+C     use of estimated tensors (linearized model) as initial values
+C     for nonlinear regression
+C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine d2rall(D,rho,nvox)
+        implicit none
+        integer nvox
+        double precision D(6,nvox),rho(6,nvox)
+        integer i,ierr
+        double precision ew(3),ev(3,3),r1,r2,r3,r4,r5
+        DO i=1,nvox
+            call eigen3(D(1,i),ew,ev,ierr)
+            if(ew(1).le.1.d-6) THEN
+              rho(1,i) = 1.d-2
+              rho(2,i) = 0.d0
+              rho(3,i) = 0.d0
+              rho(4,i) = 1.d-2
+              rho(5,i) = 0.d0
+              rho(6,i) = 1.d-2
+            ELSE
+              r1=sqrt(max(1d-12,D(1,i)))
+              r2=D(2,i)/r1
+              r3=D(3,i)/r1
+              r4=sqrt(max(1d-12,D(4,i)-r2*r2))
+              r5=(D(5,i)-r2*r3)/r4
+              rho(6,i)=sqrt(max(1d-16,D(6,i)-r3*r3-r5*r5))
+              rho(5,i)=r5
+              rho(4,i)=r4
+              rho(3,i)=r3
+              rho(2,i)=r2
+              rho(1,i)=r1
+            END IF
+        END DO
+        RETURN
+        END
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C     get D from rho
+C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine r2dall(rho,D,nvox)
+      implicit none
+      integer nvox,i
+      double precision D(6,nvox),rho(6,nvox),eps
+      double precision r1,r2,r3,r4,r5,r6
+      eps=0.d-12
+      DO i=1,nvox
+          r1=rho(1,i)
+          r2=rho(2,i)
+          r3=rho(3,i)
+          r4=rho(4,i)
+          r5=rho(5,i)
+          r6=rho(6,i)
+          D(1,i)=r1*r1+eps
+          D(2,i)=r1*r2
+          D(3,i)=r1*r3
+          D(4,i)=r2*r2+r4*r4+eps
+          D(5,i)=r2*r3+r4*r5
+          D(6,i)=r3*r3+r5*r5+r6*r6+eps
+      END DO
+C      call testreg2(D,rho,111)
+      RETURN
+      END
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C     get D from rho
+C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine rho2D(rho,D)
+      implicit none
+      double precision D(6),rho(6),eps
+      eps=0.d-12
+      D(1)=rho(1)*rho(1)+eps
+      D(2)=rho(1)*rho(2)
+      D(3)=rho(1)*rho(3)
+      D(4)=rho(2)*rho(2)+rho(4)*rho(4)+eps
+      D(5)=rho(2)*rho(3)+rho(4)*rho(5)
+      D(6)=rho(3)*rho(3)+rho(5)*rho(5)+rho(6)*rho(6)+eps
+C      call testreg2(D,rho,111)
+      RETURN
+      END
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C     get D from rho without regularization
+C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine rho2D0(rho,D)
+      implicit none
+      double precision D(6),rho(6),r1,r2,r3,r4,r5,r6
+      r1=rho(1)
+      r2=rho(2)
+      r3=rho(3)
+      r4=rho(4)
+      r5=rho(5)
+      r6=rho(6)
+      D(1)=r1*r1
+      D(2)=r1*r2
+      D(3)=r1*r3
+      D(4)=r2*r2+r4*r4
+      D(5)=r2*r3+r4*r5
+      D(6)=r3*r3+r5*r5+r6*r6
+      RETURN
+      END
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+C
+C     calculate fitted values of si
+C
+CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
+      subroutine sihat(th0i,Di,btb,F,nb)
+      implicit none
+      integer nb
+      double precision th0i,Di(6),btb(6,nb),F(nb)
+      integer j,k
+      double precision z
+      DO k=1,nb
+        z=0.d0
+        DO j=1,6
+          z=z+btb(j,k)*Di(j)
+        END DO
+        F(k)=th0i*exp(-z)
+      END DO
+      RETURN
+      END
+
+      double precision function ddot3sq(phi,eta,g)
+C  compute (g^T n(phi,eta))^2
+      implicit none
+      double precision phi,eta,g(3),sphi,z
+      sphi=dsin(phi)
+      z=g(1)*dcos(eta)*sphi+g(2)*dsin(eta)*sphi+g(3)*dcos(phi)
+      ddot3sq=z*z
+      RETURN
+      END
+      subroutine dgtddphi(phi,eta,g, d)
+C  compute (g^T n(phi,eta))^2
+C           d(g^T n(phi,eta))^2 / d phi
+C           d(g^T n(phi,eta))^2 / d eta
+C  as components of d
+      implicit none
+      double precision phi,eta,g(3),sphi,cphi,ceta,seta,z,ze,zp,d(3)
+      sphi=dsin(phi)
+      cphi=dcos(phi)
+      seta=dsin(eta)
+      ceta=dcos(eta)
+      z=g(1)*ceta*sphi+g(2)*seta*sphi+g(3)*cphi
+      zp=g(1)*ceta*cphi+g(2)*seta*cphi-g(3)*sphi
+      ze=g(2)*ceta*sphi-g(1)*seta*sphi
+      d(1)=z*z
+      d(2)=2.d0*z*zp
+      d(3)=2.d0*z*ze
+      RETURN
+      END
+      subroutine besselq(x,n,fw)
+      implicit none
+      integer n
+      double precision x(n),fw(n)
+      external besseli
+      double precision besseli
+      integer i
+      DO i=1,n
+          x(i)=i*1.d-2
+C  avoid transform to zero for numerical stability
+          fw(i)=besseli(x(i),1.d0,2.d0)/besseli(x(i),0.d0,2.d0)
+      END DO
+      RETURN
+      END
